# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2020-06-10 13:23
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_dashboard', '0003_auto_20200522_1516'),
    ]

    operations = [
        migrations.AlterField(
            model_name='dashboard',
            name='is_backlink',
            field=models.BooleanField(default=False, help_text='(DEPRECIATED) set automatically to indicate the Model is a backlink'),
        ),
    ]
